@@ -755,7 +755,10 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
             files = sorted(
                 list(
                     filter(
-                        lambda x: x.startswith(state.id_process),
+                        lambda x: (
+                            x.startswith(state.id_process)
+                            and x.endswith('.bck')
+                        ),
                         os.listdir(f"{self.path_backup}/")
                     )
                 ),
@@ -777,7 +780,10 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
         if self.erase_folder:
             files = list(
                 filter(
-                    lambda x: x.startswith(state.id_process),
+                    lambda x: (
+                        x.startswith(state.id_process)
+                        and x.endswith('.bck')
+                    ),
                     os.listdir(f"{self.path_backup}/")
                 )
             )
@@ -797,7 +803,10 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
         if isinstance(exception, KeyboardInterrupt) and self.erase_folder:
             files = list(
                 filter(
-                    lambda x: x.startswith(state.id_process),
+                    lambda x: (
+                        x.startswith(state.id_process)
+                        and x.endswith('.bck')
+                    ),
                     os.listdir(f"{self.path_backup}/")
                 )
             )
@@ -959,9 +968,21 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
         être inclu à l'intérieur de la classe du réseau). Explicitement 
         l'instanciation sera faite dans la méthode fit sera du type :
             lr_scheduler(self.optimizer, **scheduler_kwargs)
+    state_dict: Optional[Dict[str, Any]]
+        Paramètre du sceduler que l'on souhaite reprendre au moment de son
+        chargement.
     by_step: bool (=False)
         Détermine si le LRScheduler est appelé à la fin de la phase 
         d'évaluation (=False) ou à la fin de chaque step de train (=True).
+    path_backup: Optional[str]
+        Chemin vers lequel le backup de l'état de LRScheduler sera sauvegardé.
+        Si None aucun backup ne sera réalisé.
+    n_iter: int (=1_000)
+        Nombre d'itération entre deux backup.
+    erase_folder: bool (=True)
+        Effase le répertoire une fois l'entrainement fini ou arrêté.
+    nb_backup: Optinal[int]
+        Nombre de backup préservé. Si None préserve tous les backups.
     verbose: bool (=False)
         Permet d'affichier le lerning rate initial et les évolutions du 
         learning rate quand ils ont lieu. Par défaut cette argument est 
@@ -978,7 +999,12 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
     """
     lr_scheduler: Callable
     scheduler_kwargs: Dict[str, Any] = field(default_factory=dict)
+    state_dict: Optional[Dict[str, Any]] = None
     by_step: bool = False
+    path_backup: Optional[str] = None
+    n_iter: int = 1_000
+    erase_folder: bool = True
+    nb_backup: Optional[int] = None
     verbose: bool = False
 
     def __post_init__(self):
@@ -988,6 +1014,9 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                 "être appliqué durant la phase d'entrainement, mais seulement "
                 "durant la phase d'évaluation."
             )
+        if self.path_backup:
+            if not os.path.exists(self.path_backup):
+                os.makedirs(self.path_backup)
 
     def begin_train(
         self,
@@ -1002,6 +1031,12 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
             model.optimizer,
             **self.scheduler_kwargs
         )
+        if self.state_dict:
+            print(
+                "Chargement de paramètres du Learning Rate Scheduler :"
+            )
+            print(self.state_dict)
+            self.scheduler.load_state_dict(self.state_dict)
         if self.verbose:
             self.old_lr = model.optimizer.state_dict()['param_groups'][0]['lr']
             print(
@@ -1058,6 +1093,78 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                         flush=True
                     )
                     self.old_lr = lr
+        if self.path_backup:
+            if state.n_iter % self.n_iter == 0:
+                pkl.dump(
+                    self.scheduler.state_dict(),
+                    open(
+                        f"{self.path_backup}/{state.id_process}_{state.n_iter}.lsc",
+                        "wb"
+                    )
+                )
+            if self.nb_backup:
+                files = sorted(
+                    list(
+                        filter(
+                            lambda x: (
+                                x.startswith(state.id_process)
+                                and x.endswith('.lsc')
+                            ),
+                            os.listdir(f"{self.path_backup}/")
+                        )
+                    ),
+                    key=lambda x: os.path.getmtime(x),
+                    reverse=True
+                )[self.nb_backup:]
+                for file in files:
+                    os.remove(f"{self.path_backup}/{file}")
+
+    def end_train(
+        self,
+        model: PyTorchEstimators,
+        data: List[Dict[str, Tensor]],
+        state: FitState,
+        control: FitControl,
+        res_loss: float,
+        **kwargs
+    ) -> None:
+        if self.path_backup:
+            if self.erase_folder:
+                files = list(
+                    filter(
+                        lambda x: (
+                            x.startswith(state.id_process)
+                            and x.endswith('.lsc')
+                        ),
+                        os.listdir(f"{self.path_backup}/")
+                    )
+                )
+                for file in files:
+                    os.remove(f"{self.path_backup}/{file}")
+
+    def error_interrupt(
+        self,
+        model: PyTorchEstimators,
+        data: List[Dict[str, Tensor]],
+        state: FitState,
+        control: FitControl,
+        res_loss: float,
+        exception: Exception,
+        **kwargs
+    ) -> None:
+        if self.path_backup:
+            if isinstance(exception, KeyboardInterrupt) and self.erase_folder:
+                files = list(
+                    filter(
+                        lambda x: (
+                            x.startswith(state.id_process)
+                            and x.endswith('.lsc')
+                        ),
+                        os.listdir(f"{self.path_backup}/")
+                    )
+                )
+                for file in files:
+                    os.remove(f"{self.path_backup}/{file}")
 
 
 @dataclass
